"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const AbstractRandomNumber_1 = __importDefault(require("./AbstractRandomNumber"));
const Configuration_1 = __importDefault(require("../shared/config/Configuration"));
const RandomNumber_1 = __importDefault(require("./RandomNumber"));
const NumberLength_1 = __importDefault(require("./NumberLength"));
class RandomNumberTimestampBased extends AbstractRandomNumber_1.default {
    constructor(NumberConfiguration) {
        super(NumberConfiguration);
        this._padLength = new NumberLength_1.default(0);
        this._timestamp = Date.now();
        this._timestampLength = new NumberLength_1.default(this._timestamp.toString().length);
        this._value = this._generate();
    }
    _generate() {
        this._verifyLength();
        let value = this._timestamp.toString();
        const numberLength = this.getLength().getValue();
        if (numberLength > this._timestampLength.getValue()) {
            value += this._generatePad().getValue().toString();
        }
        return super._increaseNumberRandomness(parseInt(value));
    }
    _verifyLength() {
        let touched = false;
        const timestampLength = this._timestampLength.getValue();
        if (this.getConfiguration().getMinLength().getValue() < timestampLength) {
            this.getConfiguration().setMinLength(timestampLength);
            touched = true;
        }
        if (this.getConfiguration().getMaxLength().getValue() < timestampLength) {
            const maxLengthConfig = new Configuration_1.default();
            maxLengthConfig.setLength(NumberLength_1.default.getMaxSafeLength());
            this.getConfiguration().setMaxLength(new RandomNumber_1.default(maxLengthConfig).getValue());
            touched = true;
        }
        if (touched) {
            this._calculateLength();
        }
    }
    _generatePad() {
        const numberLength = this.getLength().getValue();
        const padConfig = new Configuration_1.default();
        this._padLength = new NumberLength_1.default(numberLength - this._timestampLength.getValue());
        padConfig.setLength(this._padLength.getValue());
        return new RandomNumber_1.default(padConfig);
    }
}
exports.default = RandomNumberTimestampBased;
